@@ -62,7 +62,7 @@ class ImplicitApiPlugin(BasePlugin):
             "Method _setup_api_properties() must be implemented in a subclass of ImplicitApiPlugin"
         )
 
-    @cw_timer(prefix="Plugin-ImplicitApi")  # type: ignore[no-untyped-call]
+    @cw_timer(prefix="Plugin-ImplicitApi")
     def on_before_transform_template(self, template_dict):  # type: ignore[no-untyped-def]
         """
         Hook method that gets called before the SAM template is processed.
@@ -242,7 +242,7 @@ class ImplicitApiPlugin(BasePlugin):
         Handles case where API id is not specified or is a reference to a logical id.
         """
         api_id = event_properties.get(self.api_id_property)
-        return Api.get_rest_api_id_string(api_id)  # type: ignore[no-untyped-call]
+        return Api.get_rest_api_id_string(api_id)
 
     def _maybe_add_condition_to_implicit_api(self, template_dict):  # type: ignore[no-untyped-def]
         """
