@@ -1,9 +1,8 @@
-# flake8: noqa
-#
 # Root of the SAM package where we expose public classes & methods for other consumers of this SAM Translator to use.
 # This is essentially our Public API
 #
 
+__all__ = ["Translator", "ManagedPolicyLoader"]
+
 from samtranslator.translator.translator import Translator
 from samtranslator.translator.managed_policy_translator import ManagedPolicyLoader
-
